@@ -4,16 +4,10 @@
 #ifdef HAVE_PLURAL
 
 #ifdef PLURAL_INTERNAL_DECLARATIONS
-#include <polys/nc/nc.h>
+#include "polys/nc/nc.h"
 
-struct  spolyrec; typedef struct spolyrec    polyrec; typedef polyrec *          poly;
-struct ip_sring; typedef struct ip_sring *         ring;
-struct sip_sideal; typedef struct sip_sideal *       ideal;
-
-class intvec;
-
-extern NF_Proc nc_NF;
-extern BBA_Proc gnc_gr_bba, gnc_gr_mora, sca_bba, sca_mora, sca_gr_bba;
+EXTERN_VAR NF_Proc nc_NF;
+EXTERN_VAR BBA_Proc gnc_gr_bba, gnc_gr_mora, sca_bba, sca_mora, sca_gr_bba;
 
 /* the realiziation of the routines above in libkernel:*/
 ideal k_gnc_gr_bba(const ideal, const ideal, const intvec *, const intvec *, kStrategy, const ring _currRing);
